from .. import Provider as BaseProvider

# Source: ONISEP
# data.gouv.fr/s/resources/liste-des-metiers-onisep/20150112-173428/metier.csv


class Provider(BaseProvider):
    jobs = ["Accessoiriste",
            "Accompagnateur de moyenne montagne",
            "Accompagnateur de tourisme équestre",
            "Accompagnateur de voyages",
            "Acheteur",
            "Acheteur d'espaces publicitaires",
            "Acousticien",
            "Actuaire",
            "Adjoint",
            "Administrateur de base de données",
            "Administrateur de biens",
            "Administrateur de logiciels de laboratoire",
            "Administrateur de mission humanitaire",
            "Administrateur de réseau",
            "Administrateur de spectacle",
            "Administrateur judiciaire ",
            "Agenceur de cuisines et salles de bains",
            "Agent",
            "Agent artistique",
            "Agent d'assurances ",
            "Agent de développement des énergies renouvelables",
            "Agent de développement local",
            "Agent de développement touristique",
            "Agent de la surveillance SNCF",
            "Agent de propreté et d'hygiène",
            "Agent de propreté urbaine",
            "Agent de sécurité",
            "Agent de service commercial train",
            "Agent des méthodes",
            "Agent de transit",
            "Agriculteur",
            "Agronome",
            "Aide médico-psychologique",
            "Aide-soignant",
            "Ajusteur",
            "Ambulancier",
            "Analyste de crédit",
            "Analyste financier",
            "Anatomiste",
            "Anesthésiste-réanimateur",
            "Animalier de laboratoire",
            "Animateur",
            "Animateur 2D et 3D",
            "Animateur d'activités physiques et sportives",
            "Animateur de bassin versant",
            "Animateur de radio et de télévision",
            "Animateur du patrimoine",
            "Animateur nature",
            "Antiquaire",
            "Apiculteur",
            "Aquaculteur",
            "Arboriculteur",
            "Architecte",
            "Architecte d'intérieur",
            "Architecte naval ",
            "Architecte produit industriel",
            "Architecte réseau",
            "Architecte web",
            "Archiviste",
            "Archéologue",
            "Aérodynamicien",
            "Aromaticien",
            "Artiste de cirque",
            "Ascensoriste",
            "Assistant",
            "Assistant",
            "Assistant",
            "Assistant de gestion en PME",
            "Assistant dentaire",
            "Assistant de service social",
            "Assistant en ressources humaines",
            "Astrophysicien",
            "Attaché",
            "Attaché",
            "Attaché d'administration",
            "Attaché de presse",
            "Attaché de recherche clinique",
            "Audioprothésiste",
            "Auditeur externe",
            "Auditeur interne",
            "Auteur interprète",
            "Auxiliaire de puériculture",
            "Auxiliaire de vie sociale",
            "Auxiliaire spécialisé vétérinaire",
            "Avocat",
            "Bactériologiste",
            "Barman ",
            "Batelier",
            "Bibliothécaire",
            "Bijoutier",
            "Bio-informaticien",
            "Biologiste en environnement",
            "Biologiste médical",
            "Biostatisticien",
            "Ébéniste",
            "Botaniste",
            "Bottier",
            "Boucher",
            "Boulanger",
            "Brodeur",
            "Bronzier",
            "Cadreur",
            "Caissier",
            "Canalisateur",
            "Carreleur-mosaïste",
            "Carrossier ",
            "Cartographe",
            "Caviste",
            "Chanteur",
            "Charcutier",
            "Chargé",
            "Chargé d'affaires en génie climatique",
            "Chargé d'affaires en génie mécanique",
            "Chargé de clientèle banque",
            "Chargé de communication interne",
            "Chargé de pharmacovigilance",
            "Chargé de production",
            "Chargé de projet événementiel",
            "Chargé de recherche en acoustique musicale",
            "Chargé de recherche et développement déchets",
            "Chargé de référencement web",
            "Chargé des méthodes outils et qualité en informatique",
            "Chargé des relations publiques",
            "Chargé de veille législative et réglementaire",
            "Chargé d'études économiques",
            "Chargé d'études en aménagement",
            "Chargé d'études en marketing",
            "Chargé d'études en valorisation agricole des déchets",
            "Chargé d'études média",
            "Chargé d'études naturalistes",
            "Chargé d'études ressources humaines",
            "Charpentier bois",
            "Charpentier métallique",
            "Chaudronnier",
            "Chauffeur de taxi",
            "Chef comptable",
            "Chef de chantier",
            "Chef de chantier en installations électriques",
            "Chef de cultures légumières",
            "Chef de fabrication des industries graphiques",
            "Chef de mission humanitaire",
            "Chef de produit marketing",
            "Chef de produit touristique",
            "Chef de projet biodiversité",
            "Chef de projet démantèlement nucléaire",
            "Chef de projet informatique",
            "Chef de projet multimédia",
            "Chef de projet éolien",
            "Chef de projet sites et sols pollués",
            "Chef de projet territorial",
            "Chef de publicité",
            "Chef de rayon",
            "Chef de station de traitement des eaux",
            "Chef des ventes",
            "Chef d'exploitation d'usine d'incinération",
            "Chef monteur",
            "Chercheur en biologie",
            "Chercheur en biologie du sport",
            "Chercheur en chimie",
            "Chercheur en physique   ",
            "Chirurgien",
            "Chirurgien-dentiste",
            "Éclairagiste",
            "Clerc d'huissier",
            "Climatologue",
            "Coffreur",
            "Cogniticien",
            "Coiffeur",
            "Collaborateur de notaire",
            "Collecteur de fonds",
            "Comédien",
            "Commerçant en alimentation",
            "Commercial export",
            "Commissaire de police",
            "Commissaire-priseur",
            "Comptable",
            "Concepteur",
            "Concepteur de jeux vidéo",
            "Concepteur de niveaux de jeu web",
            "Concepteur multimédia",
            "Conducteur",
            "Conducteur de bus ou d'autocar",
            "Conducteur de ligne de production alimentaire",
            "Conducteur de machines agricoles",
            "Conducteur de machines à imprimer ",
            "Conducteur de machines à papier ",
            "Conducteur de métro",
            "Conducteur d'engins de travaux publics",
            "Conducteur de scierie",
            "Conducteur de train / TGV",
            "Conducteur de travaux",
            "Économe de flux",
            "Économiste de la construction",
            "Conseiller agricole",
            "Conseiller d'éducation",
            "Conseiller d'insertion et de probation",
            "Conseiller d'orientation-psychologue",
            "Conseiller en économie sociale et familiale",
            "Conseiller en environnement",
            "Conseiller en fusion-acquisition",
            "Conseiller en génétique",
            "Conseiller en insertion sociale et professionnelle",
            "Conseiller en salle de remise en forme",
            "Conseiller en séjours",
            "Conseiller en voyages",
            "Conseiller espace info-énergie",
            "Conservateur du patrimoine",
            "Consignataire de navire",
            "Constructeur de routes",
            "Consultant",
            "Consultant en solutions intégrées",
            "Consultant en validation",
            "Consultant green IT",
            "Contrôleur",
            "Contrôleur",
            "Contrôleur de gestion",
            "Contrôleur de performances",
            "Contrôleur technique automobile",
            "Convoyeur de fonds",
            "Coordonnateur d'études cliniques",
            "Cordiste",
            "Cordonnier",
            "Correcteur",
            "Costumier",
            "Courtier",
            "Couvreur",
            "Céramiste",
            "Credit manager",
            "Cuisinier",
            "Danseur",
            "Déclarant en douane",
            "Décolleteur",
            "Décorateur scénographe",
            "Designer",
            "Designer d'interaction",
            "Designer sonore",
            "Dessinateur BTP",
            "Dessinateur de BD",
            "Dessinateur en construction mécanique",
            "Directeur",
            "Directeur artistique",
            "Directeur d'agence bancaire",
            "Directeur de centre pénitentiaire",
            "Directeur de création",
            "Directeur de la photographie",
            "Directeur de magasin à grande surface",
            "Directeur de restaurant",
            "Directeur d'hôpital",
            "Directeur d'hôtel",
            "Directeur d'office de tourisme",
            "Éditeur",
            "Diététicien",
            "Déménageur",
            "Démographe",
            "Documentaliste",
            "Domoticien",
            "Dépanneur en électroménager",
            "Dresseur d'animaux",
            "Éducateur",
            "Éducateur",
            "Éducateur",
            "Éducateur de jeunes enfants",
            "Éducateur de la protection judiciaire de la jeunesse",
            "Développeur économique",
            "Développeur d'applications mobiles",
            "Développeur humanitaire",
            "Développeur informatique",
            "Employé de pressing",
            "Employé de restaurant",
            "Encadreur",
            "Enquêteur privé",
            "Enseignant",
            "Enseignant",
            "Enseignant d'art",
            "Enseignant de la conduite automobile et de la sécurité routière",
            "Enseignant humanitaire",
            "Entraîneur ",
            "Entraîneur de chevaux",
            "Ergonome",
            "Ergothérapeute",
            "Esthéticien",
            "Ethnologue",
            "Expert automobile",
            "Expert bilan carbone",
            "Expert-comptable",
            "Expert en sécurité informatique",
            "Expert immobilier",
            "Façadier",
            "Facteur",
            "Facteur d'instruments",
            "Façonnier des industries graphiques",
            "Femme de chambre ",
            "Ferronnier d'art",
            "Fiscaliste",
            "Fleuriste",
            "Formateur d'adultes",
            "Formateur en informatique",
            "Formulateur",
            "Frigoriste",
            "Garde ",
            "Garde à cheval",
            "Gardien de la paix",
            "Gardien de police municipale",
            "Garçon de café",
            "Gendarme",
            "Gestionnaire de contrats d'assurance",
            "Gestionnaire de contrats informatiques",
            "Gestionnaire de données cliniques",
            "Gestionnaire de patrimoine",
            "Gestionnaire de portefeuille",
            "Généticien",
            "Géochimiste",
            "Géographe",
            "Géologue",
            "Géologue minier",
            "Géologue modélisateur",
            "Géomaticien",
            "Géomètre-topographe",
            "Géophysicien",
            "Géotechnicien",
            "Géothermicien",
            "Gouvernante",
            "Gérant de restauration collective",
            "Graphiste",
            "Greffier",
            "Grutier",
            "Guichetier",
            "Guide conférencier des villes et pays d'art et d'histoire",
            "Guide de haute montagne",
            "Guide-interprète",
            "Halieute",
            "Histologiste",
            "Horloger",
            "Horticulteur",
            "Hot liner",
            "Hôte d'accueil",
            "Hôtesse de l'air ",
            "Huissier de justice",
            "Hydraulicien",
            "Hydrogéologue",
            "Hydrologue",
            "Iconographe",
            "Illustrateur",
            "Infirmier",
            "Infirmier humanitaire",
            "Informaticien",
            " ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur analyste de l'air",
            "Ingénieur brevets",
            "Ingénieur calcul",
            "Ingénieur chimiste",
            "Ingénieur chimiste en développement analytique",
            "Ingénieur cloud computing",
            "Ingénieur d'application",
            "Ingénieur de la police technique et scientifique",
            "Ingénieur du BTP",
            "Ingénieur du son",
            "Ingénieur efficacité énergétique du bâtiment",
            "Ingénieur en aéronautique",
            "Ingénieur en automatisme",
            "Ingénieur en construction automobile",
            "Ingénieur en construction navale",
            "Ingénieur en génie climatique",
            "Ingénieur en informatique",
            "Ingénieur en électronique numérique",
            "Ingénieur en mécanique",
            "Ingénieur en mécanique",
            "Ingénieur en métrologie",
            "Ingénieur en énergie solaire",
            "Ingénieur en production et expérimentations végétales",
            "Ingénieur en R et D en énergies renouvelables",
            "Ingénieur environnement",
            "Ingénieur environnement et risques industriels",
            "Ingénieur essais",
            "Ingénieur fluides, énergies, réseaux, environnement",
            "Ingénieur forage",
            "Ingénieur gaz",
            "Ingénieur hydroécologue",
            "Ingénieur hydrogéomorphologue",
            "Ingénieur maintenance aéronautique",
            "Ingénieur métallurgiste",
            "Ingénieur méthodes mécaniques",
            "Ingénieur nucléaire",
            "Ingénieur plasturgiste",
            "Ingénieur procédés en chimie",
            "Ingénieur process aval",
            "Ingénieur production dans les biotechnologies",
            "Ingénieur production en mécanique",
            "Ingénieur radioprotection",
            "Ingénieur recherche et développement en agroalimentaire",
            "Ingénieur réservoir",
            "Ingénieur structures",
            "Ingénieur système",
            "Ingénieur systèmes embarqués",
            "Ingénieur technico-commerciale en électronique",
            "Ingénieur technico-commercial en chimie",
            "Ingénieur textile",
            "Ingénieur télécoms et réseaux",
            "Ingénieur études et développement en logiciels de simulation",
            "Inspecteur",
            "Inspecteur de banque",
            "Inspecteur du permis de conduire et de la sécurité routière",
            "Installateur en télécoms",
            "Intégrateur web",
            "Journaliste",
            "Journaliste reporter d'images ",
            "Juge des enfants",
            "Juge d'instance",
            "Juge d'instruction",
            "Juriste d'entreprise",
            "Juriste droit de l'environnement",
            "Juriste en droit social",
            "Juriste en propriété intellectuelle",
            "Lad-jockey, lad-driver",
            "Élagueur",
            "Électricien",
            "Électromécanicien ",
            "Électronicien automobile",
            "Éleveur",
            "Libraire",
            "Linguiste",
            "Logisticien",
            "Machiniste constructeur ou plateau",
            "Magasinier cariste",
            "Magistrat",
            "Manager de risques",
            "Mandataire judiciaire",
            "Manipulateur en électroradiologie médicale",
            "Maçon",
            "Maquettiste",
            "Maraîcher",
            "Maréchal",
            "Marchandiseur",
            "Marin de commerce",
            "Marin pêcheur",
            "Maroquinier",
            "Masseur-kinésithérapeute",
            "Matelot",
            "Maître-chien",
            "Maître  d'hôtel",
            "Maître nageur sauveteur",
            "Mécanicien",
            "Mécanicien",
            "Mécanicien bateaux",
            "Mécanicien d'entretien d'avion",
            "Mécanicien en matériel agricole",
            "Mécanicien moto",
            "Mécatronicien",
            "Médecin généraliste",
            "Médecin humanitaire",
            "Médecin spécialiste",
            "Médiateur",
            "Menuisier",
            "Microbiologiste",
            "Microtechnicien",
            "Militaire du rang ",
            "Militaire technicien",
            "Mixeur",
            "Modiste",
            "Modéliste",
            "Moniteur",
            "Moniteur de ski",
            "Moniteur d'équitation",
            "Monteur",
            "Monteur en installations thermiques et climatiques",
            "Monteur en réseaux de distribution électrique",
            "Mouleur",
            "Météorologiste",
            "Musicien",
            "Neurobiologiste",
            "Notaire",
            "Océanologue",
            "Oenologue",
            "Officier",
            "Officier de gendarmerie",
            "Officier de la marine marchande",
            "Officier de l'armée de l'air",
            "Officier de l'armée de terre",
            "Officier de marine",
            "Officier de police",
            "Opérateur de fabrication de produits alimentaires",
            "Opérateur de raffinerie",
            "Opérateur en traitement des matériaux",
            "Opérateur prépresse",
            "Opérateur sur machine à commande numérique",
            "Opticien",
            "Optronicien",
            "Orfèvre",
            "Orthophoniste",
            "Orthoprothésiste",
            "Orthoptiste",
            "Ostéopathe",
            "Ouvrier",
            "Ouvrier agricole",
            "Ouvrier paysagiste",
            "Palefrenier",
            "Paléontologue",
            "Parfumeur",
            "Paysagiste",
            "Pédiatre",
            "Pédicure-podologue",
            "Pédologue",
            "Peintre en bâtiment",
            "Pharmacien",
            "Pharmacien dans l'industrie",
            "Photographe",
            "Pilote de ligne",
            "Pilote de ligne automatisée ",
            "Plombier",
            "Plâtrier",
            "Podo-orthésiste",
            "Professeur dans l'enseignement agricole",
            "Professeur d'éducation physique et sportive",
            "Professeur de collège et de lycée",
            "Professeur de lycée professionnel ou technique ",
            "Professeur de maths ou de physique-chimie",
            "Professeur de musique et de danse",
            "Professeur des écoles ",
            "Professeur documentaliste",
            "Projectionniste",
            "Prothésiste dentaire",
            "Préparateur en pharmacie",
            "Psychanalyste",
            "Psychologue",
            "Psychomotricien",
            "Pâtissier",
            "Puériculteur",
            "Qualiticien",
            "Réceptionniste",
            "Rédacteur",
            "Rédacteur en chef",
            "Rédacteur on line",
            "Relieur",
            "Reporter-photographe",
            "Responsable assurance qualité",
            "Responsable biométrie",
            "Responsable de fabrication en agroalimentaire",
            "Responsable de formation",
            "Responsable de laboratoire de contrôle en biologie",
            "Responsable de la collecte des déchets ménagers",
            "Responsable de la promotion des ventes",
            "Responsable de la rémunération",
            "Responsable de plate-forme biotechnologique",
            "Responsable de projets culturels",
            "Responsable de réseau d'assainissement",
            "Responsable de réseau eau potable",
            "Responsable de scierie",
            "Responsable de site de traitement des déchets",
            "Responsable des ressources humaines",
            "Responsable d'ordonnancement",
            "Responsable du back-office",
            "Responsable du recrutement",
            "Responsable du service après-vente",
            "Responsable du soutien logistique intégré",
            "Responsable micro",
            "Responsable qualité en agroalimentaire",
            "Restaurateur d'oeuvres d'art",
            "Régisseur cinéma",
            "Régisseur de spectacles",
            "Régleur",
            "Rudologue",
            "Sage-femme ",
            "Salesman",
            "Sapeur",
            "Scénariste",
            "Scripte",
            "Secrétaire",
            "Secrétaire administratif",
            "Secrétaire d'édition",
            "Secrétaire de rédaction",
            "Secrétaire des Affaires étrangères",
            "Secrétaire juridique",
            "Secrétaire médical",
            "Sellier",
            "Serrurier",
            "Sociologue",
            "Soigneur",
            "Solier-moquettiste",
            "Sommelier",
            "Soudeur",
            "Souffleur de verre ",
            "Souscripteur",
            "Sous-officier de l'armée de l'air",
            "Sous-officier de l'armée de terre",
            "Spécialiste des affaires réglementaires en chimie",
            "Sportif de haut niveau",
            "Sérigraphe",
            "Staffeur-ornemaniste",
            "Statisticien",
            "Styliste ",
            "Substitut du procureur",
            "Surveillant de centre pénitentiaire",
            "Syndic de copropriété",
            "Tailleur",
            "Tailleur de pierre",
            "Étalagiste",
            "Étanchéiste",
            "Tapissier d'ameublement ",
            "Technicien ",
            "Technicien ",
            "Technicien",
            "Technicien",
            "Technicien",
            "Technicien automobile",
            "Technicien biologiste",
            "Technicien chimiste",
            "Technicien céramiste",
            "Technicien d'analyses biomédicales",
            "Technicien de fabrication de mobilier et de menuiserie",
            "Technicien de forge",
            "Technicien de l'intervention sociale et familiale",
            "Technicien de maintenance en génie climatique",
            "Technicien de maintenance en informatique",
            "Technicien de maintenance industrielle",
            "Technicien de police technique et scientifique",
            "Technicien des industries du verre",
            "Technicien d'essais",
            "Technicien d'exploitation de l'eau",
            "Technicien d'exploitation du réseau gaz",
            "Technicien d'intervention clientèle gaz",
            "Technicien en automatismes",
            "Technicien en engins de travaux publics",
            "Technicien en lignes haute tension ",
            "Technicien en métrologie",
            "Technicien en optique de précision",
            "Technicien en traitement des déchets",
            "Technicien nucléaire",
            "Technicien paysagiste",
            "Technicien plasturgiste",
            "Technicien télécoms et réseaux",
            "Technico-commercial en agroalimentaire",
            "Techniverrier",
            "Teinturier",
            "Testeur en informatique",
            "Télévendeur",
            "Toiletteur d'animaux",
            "Tonnelier",
            "Trader",
            "Traducteur-interprète",
            "Urbaniste",
            "Veilleur stratégique",
            "Vendeur-conseil en matériel agricole",
            "Vendeur en animalerie",
            "Vendeur en fournitures automobiles",
            "Vendeur en magasin",
            "Vendeur en micro-informatique et multimédia",
            "Verrier au chalumeau",
            "Visiteur",
            "Viticulteur",
            "Vitrailliste",
            "Volcanologue",
            "Vétérinaire",
            "Webdesigner",
            "Webmestre",
            "Zoologiste"]
