from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """
    List of 2000 most frequent words in Polish Wiktionary

    https://pl.wiktionary.org/wiki/Indeks:Polski_-_Najpopularniejsze_s%C5%82owa_1-2000
    """

    word_list = (
        'w', 'z', 'być', 'na', 'i', 'do', 'nie', 'to', 'który', 'lub', 'się', 'mieć', 'o', 'coś', 'ten', 'dotyczyć',
        'co', 'on', 'ktoś', 'od', 'język', 'że', 'po', 'przez', 'ja', 'jeden', 'miasto', 'za', 'osoba', 'jak', 'rok',
        'cecha', 'a', 'bardzo', 'taki', 'mój', 'człowiek', 'imię', 'swój', 'dla', 'związać', 'część', 'kobieta', 'dwa',
        'móc', 'ona', 'pan', 'nasz', 'jakiś', 'mały', 'ze', 'miejsce', 'inny', 'bez', 'czas', 'duży', 'związany',
        'praca', 'czy', 'ale', 'pies', 'sposób', 'Polska', 'rodzaj', 'tylko', 'dom', 'dziecko', 'np.', 'ty', 'dzień',
        'mieszkaniec', 'jako', 'rzeka', 'przed', 'pani', 'męski', 'woda', 'tak', 'pod', 'dobry', 'już', 'państwo',
        'rodzina', 'zostać', 'życie', 'mówić', 'zwierzę', 'nad', 'pierwszy', 'ta', 'przy', 'wiele', 'cały', 'roślina',
        'u', 'sobie', 'trzy', 'nowy', 'często', 'chcieć', 'kolor', 'musieć', 'używać', 'robić', 'wielki', 'żeński',
        'kraj', 'mężczyzna', 'jego', 'strona', 'wysoki', 'każdy', 'nazwa', 'gatunek', 'polski', 'iść', 'sam', 'stolica',
        'grupa', 'stary', 'my', 'zrobić', 'książka', 'kto', 'symbol', 'drugi', 'rzecz', 'stan', 'samochód', 'drzewo',
        'ptak', 'między', 'świat', 'prawo', 'sąsiad', 'droga', 'oraz', 'słowo', 'mieszkanka', 'głowa', 'liczba', 'ci',
        'oni', 'nie-', 'codziennie', 'owoc', 'gdy', 'młody', 'środek', 'zły', 'spotykać', 'bo', 'raz', 'spacer',
        'ziemia', 'liczba atomowa', 'aby', 'znajdować się', 'należeć', 'itp.', 'ojciec', 'dużo', 'wiek', 'Rosja',
        'dobrze', 'kiedy', 'służyć', 'kilka', 'przedmiot', 'ręka', 'jaki', 'biały', 'długi', 'sprawa', 'cztery',
        'siebie', 'podczas', 'ruch', 'okres', 'góra', 'żona', 'litera', 'matka', 'odnosić się', 'kupić', 'pięć',
        'widzieć', 'zawsze', 'oko', 'albo', 'zajmować się', 'jeszcze', 'stać', 'szkoła', 'forma', 'we', 'pracować',
        'cel', 'koniec', 'twój', 'ciało', 'wiedzieć', 'mieszkać', 'zwykle', 'niż', 'działanie', 'koń', 'pokój',
        'element', 'kwiat', 'nauka', 'godzina', 'wszystko', 'zawierać', 'gdzie', 'położyć', 'powiedzieć',
        'pierwiastek chemiczny', 'urządzenie', 'choroba', 'lubić', 'pochodzić', 'wyspa', 'syn', 'prowadzić', 'piękny',
        'dać', 'wszyscy', 'miesiąc', 'wieś', 'jednostka', 'ryba', 'światło', 'jeść', 'dziewczyna', 'żyć', 'by', 'dawać',
        'budynek', 'stopień', 'grać', 'herb', 'brat', 'las', 'jej', 'siła', 'obszar', 'czarny', 'nic', 'znak', 'dany',
        'one', 'żeby', 'czerwony', 'rząd', 'różny', 'brak', 'dziś', 'gra', 'leżeć', 'związek', 'członek', 'kształt',
        'chodzić', 'wykonywać', 'wartość', 'noc', 'obwód', 'sztuka', 'statek', 'teraz', 'noga', 'dźwięk', 'występować',
        'teren', 'ostatni', 'pieniądz', 'sytuacja', 'wczoraj', 'śmierć', 'tydzień', 'sklep', 'niebo', 'niektóry',
        'morze', 'ważny', 'także', 'film', 'krótki', 'Europa', 'działać', 'główny', 'tworzyć', 'wykonać', 'skóra',
        'sześć', 'tam', 'materiał', 'trwać', 'dwadzieścia', 'ilość', 'wino', 'kot', 'szybko', 'określony', 'lecz',
        'własny', 'wojna', 'pochodzenie', 'pole', 'powierzchnia', 'północny', 'flaga', 'przyjaciel', 'postać', 'znać',
        'silny', 'proces', 'władza', 'mleko', 'system', 'mięso', 'obraz', 'składać się', 'wyraz', 'tysiąc', 'głos',
        'pić', 'południowy', 'słońce', 'serce', 'początek', 'córka', 'Bóg', 'pisać', 'jechać', 'drzwi', 'twarz',
        'region', 'firma', 'miłość', 'wiatr', 'zielony', 'tekst', 'jeśli', 'zmiana', 'grecki', 'kierunek', 'siedem',
        'święty', 'nawet', 'król', 'niski', 'wolny', 'koło', 'linia', 'kawa', 'dzisiaj', 'chleb', 'ulica', 'siostra',
        'dawny', 'czyjś', '1000', 'nosić', 'problem', 'powietrze', 'włos', 'prosty', 'więc', 'układ okresowy', 'pomoc',
        'żołnierz', 'brać', 'wziąć', 'tu', 'posiadać', 'powodować', 'uważać', 'punkt', 'ogień', 'arabski', 'podobny',
        'stanowić', 'ludzie', 'charakterystyczny', 'mało', 'jezioro', 'właściwy', 'pewien', 'mąż', 'też', 'trzeci',
        'krew', 'brzeg', 'dziesięć', 'samolot', 'znaleźć', 'okno', 'znaczenie', 'osiem', 'pójść', '1', 'gwiazda',
        'informacja', 'granica', 'oddział', 'prawdziwy', 'dostać', 'powinien', 'ich', 'nigdy', 'drewno', 'stosować',
        'zbiór', 'Ukraina', 'chwila', 'ból', 'uwaga', 'niewielki', 'charakter', 'deszcz', 'czysty', 'zachowanie',
        'ciężki', 'badanie', 'ostry', 'alfabet', 'Niemcy', 'ząb', 'żaden', 'Francja', 'zacząć', 'ile', 'położenie',
        'niemiecki', 'myśleć', 'wynik', 'pracownik', 'piwo', 'walka', 'polegać', 'francuski', 'stół', 'stać się',
        'pierwiastek', 'według', 'chory', 'zasada', 'można', 'but', 'śnieg', 'pociąg', 'utwór', 'zespół', 'kościół',
        'dziewięć', 'nauczyciel', 'siedzieć', 'lekarz', 'łączyć', 'prawy', 'istnieć', 'jutro', 'trudny', 'zbyt',
        'kamień', 'jedzenie', 'liść', 'jasny', 'kultura', 'czynność', 'południe', 'numer', 'mieszkanie', 'klasa',
        'zdanie', 'historia', 'wydawać', 'ściana', 'funkcja', 'żółty', 'ubranie', 'bóg', 'muzyka', 'piec',
        'przypominać', 'uczeń', 'układ', 'księżyc', 'zwłaszcza', 'historyczny', 'komputer', 'rosnąć', 'substancja',
        'chłopiec', 'zachodni', 'również', 'prawda', 'organizm', 'pełny', 'program', 'całość', 'uczucie', 'urząd',
        'starożytny', 'typ', '2', 'polityczny', 'alkohol', 'głupi', 'północ', 'jednak', 'spać', 'pojazd', 'bliski', '5',
        'uprawiać', 'wszystkie', 'para', 'złoty', 'kraina', 'elektryczny', 'cena', 'organizacja', 'przyjść', 'około',
        'niebieski', 'prosić', 'towar', 'przypadek', 'trzeba', 'list', 'źródło', 'ludzki', 'dokument', 'społeczny',
        'herbata', 'kawałek', 'dziedzina', 'słaby', 'myśl', 'dopływ', 'wiedza', 'narzędzie', 'ani', 'lewy', 'naczynie',
        'błąd', 'szybki', 'wojskowy', 'znany', 'wieczór', 'trochę', 'wschodni', 'naturalny', 'zupa', 'pewny', 'trzymać',
        'lód', 'trzydzieści', 'może', 'szeroki', 'zjawisko', 'ogród', 'przeznaczyć', 'przeciwny', 'angielski', 'czytać',
        'ciasto', 'drobny', 'kochać', 'maszyna', 'chłopak', 'sen', 'plan', 'głównie', 'składać', 'wokół', 'produkt',
        'napój', 'wielkość', 'zdjęcie', 'zima', 'zobaczyć', 'energia', 'łóżko', 'obywatel', 'złoto', 'broń', 'tkanina',
        'słodki', 'pytanie', 'mowa', 'województwo', 'spotkanie', 'publiczny', 'obiekt', 'smak', 'karta', 'pełen',
        'większość', 'cukier', 'cześć', 'wpływ', 'wodny', '4', 'stopa', 'Włochy', 'stosunek', 'kuchnia', 'odbywać się',
        'duch', 'morski', 'w celu', 'aż', 'wybrzeże', 'pismo', 'prowincja', 'razem', 'równy', 'stały', 'pięćdziesiąt',
        'wewnątrz', 'prawie', 'gość', 'powstać', 'mocny', 'jajko', 'naród', 'potrawa', 'papier', 'butelka', 'temat',
        'żywy', 'rejon', 'zdrowie', 'lekki', 'sąd', 'palić', 'nikt', 'instrument', '3', 'wiadomość', 'produkcja', 'nos',
        'dziadek', 'palec', 'kość', 'długość', 'obejmować', 'partia', 'Afryka', 'lato', 'rola', 'zapach', 'księga',
        'policja', 'za pomocą', 'czynić', 'udział', 'czekać', 'rower', 'wszystek', 'miejscowość', 'sieć', 'babcia',
        'muzyczny', 'poza', 'odpowiedni', 'usta', 'warstwa', 'lek', 'podstawowy', 'wy', 'chemiczny', 'czterdzieści',
        'zabawa', 'szczyt', 'ponieważ', 'gmina', 'nie ma', 'warunek', 'jabłko', 'wojsko', 'wyrażać', 'powód',
        'rozumieć', 'ciemny', 'słownik', 'długo', 'mama', 'śpiewać', 'środkowy', 'podstawa', 'rano', 'opinia',
        'Hiszpania', 'wyjść', 'religia', 'pozycja', 'wschód', 'zachód', 'fala', 'wydarzenie', 'bogaty', 'piłka',
        'Ziemia', 'Azja', 'ramię', 'sześćdziesiąt', 'właśnie', 'poprzez', 'ucho', 'wypadek', 'gruby', 'nazywać', '30',
        'tytuł', 'stanowisko', 'krowa', 'szczęście', 'obok', 'oficjalny', 'poziom', 'odmiana', 'rosyjski', 'połowa',
        'rozmowa', 'gazeta', 'rodzic', 'ponad', 'potrzeba', 'szukać', 'połączenie', 'wyglądać', 'zbierać', 'rozwój',
        'pogoda', 'masa', 'pomieszczenie', 'potem', 'dzieło', 'nazwisko', 'sól', 'odpowiadać', 'całkowicie',
        'posługiwać się', 'styl', 'sto', 'strach', 'lud', 'religijny', 'papieros', 'słuchać', 'styczeń', 'podróż',
        'głęboki', 'środowisko', 'administracyjny', 'moc', 'pogląd', 'centrum', 'górski', 'święto', 'kara',
        'instytucja', 'pas', 'Grecja', 'szczęśliwy', 'pozbawić', 'zadanie', 'zaczynać', 'taniec', 'korona', 'patrzeć',
        'oznaczać', 'temperatura', 'niedziela', 'listopad', 'chmura', 'zupełnie', 'wśród', 'liczyć', '6', 'otrzymać',
        'metoda', 'ono', 'zdolność', 'gorący', 'zajmować', 'wspólny', 'miły', 'możliwość', 'ładny', 'wejść',
        'wykorzystywać', 'egzamin', 'złożyć', 'wąski', 'skrzydło', 'fizyczny', 'przestrzeń', '100', 'przedstawiać',
        'otwarty', 'komórka', 'kierować', 'nóż', 'płyn', 'gdzieś', 'budowa', 'wspaniały', 'włoski', 'płynąć',
        'więzienie', 'zazwyczaj', 'seksualny', 'szpital', 'nagle', 'grzyb', 'ciepły', 'zmieniać', 'ser', 'wewnętrzny',
        'telefon', 'dlaczego', 'stawać się', 'kupować', 'walczyć', '900', 'zamek', 'dziki', 'zimny', 'minuta',
        'wywoływać', 'obecnie', 'dusza', '8', '10', 'obiad', 'określenie', 'wysokość', 'narodowy', 'europejski',
        'założyć', 'umrzeć', 'tutaj', 'czwarty', 'domowy', 'wierzyć', 'stworzyć', 'moneta', 'wobec', 'barwa',
        'właściwość', 'istota', 'możliwy', 'metal', 'naprawdę', 'umowa', 'węgiel', 'hiszpański', 'pierś', '9', 'trawa',
        'wygląd', 'określać', 'skała', 'przyrząd', 'osiemdziesiąt', 'ogromny', 'wąż', 'ku', 'wchodzić', 'ponownie',
        'natura', 'blisko', 'obowiązek', 'gaz', 'miara', 'z powodu', 'te', 'szczególnie', 'potrzebować', 'stracić',
        'wymagać', 'ludność', 'świnia', 'wcześnie', 'bieg', 'wrogi', 'miękki', 'autobus', 'drogi', 'zakład',
        'amerykański', 'siedemdziesiąt', 'grudzień', 'obcy', 'napisać', 'kolejny', 'sobą', 'ochrona', 'akcja',
        'Szwecja', 'rzymski', 'zwolennik', 'ziemniak', 'piąty', 'zdobyć', '20', 'dach', 'należy', 'bić', 'dział',
        'jeździć', 'pomiędzy', 'klucz', 'artykuł', 'zgoda', 'dziewięćdziesiąt', 'źle', 'ofiara', 'piasek', 'nadzieja',
        'moment', 'uniwersytet', 'Warszawa', 'pamięć', 'odpowiedź', 'luty', 'użycie', 'chronić', 'próbować', 'wyrób',
        'łatwo', 'przyczyna', 'wrzesień', 'teatr', 'przyjąć', 'dodatek', 'czyli', 'specjalista', 'sok', '7', 'decyzja',
        'przemysł', 'rynek', 'owca', 'prezydent', 'spokój', 'radość', 'drużyna', 'miejski', 'wróg', 'dół', 'podawać',
        'Jan', 'kolega', 'odcień', 'zakładać', 'sportowy', 'wolność', 'znowu', 'czuć', 'ten sam', 'owad', 'zatoka',
        'działalność', 'wiosna', 'warzywo', 'pragnienie', 'ogół', 'przykład', 'górny', 'róg', 'cierpieć', 'połączyć',
        'brzuch', 'surowy', 'polityka', 'Rzym', 'uczyć się', 'ogon', 'kula', 'kąt', 'wzrost', 'dokładnie', 'bilet',
        'tamten', 'wzór', 'cienki', 'poważny', 'wychodzić', 'padać', 'właściciel', 'rozmawiać', 'student',
        'międzynarodowy', 'szósty', 'Japonia', 'poruszać się', 'porządek', 'przyjmować', 'uderzenie', 'szacunek',
        'postępowanie', 'bok', 'rada', 'skład', 'koncern', 'przynosić', 'umieć', 'drewniany', 'atak', 'nadawać',
        'pióro', 'dziać się', 'przyjęcie', 'lekcja', 'poniedziałek', 'japoński', 'tradycyjny', 'potrafić', 'obecny',
        'wnętrze', 'kwiecień', 'republika', 'naukowy', 'leczenie', 'późno', 'prąd', 'maj', 'gwałtowny', 'uczyć',
        'terytorium', 'małżeństwo', 'prasa', 'mocno', 'państwowy', 'rzucać', 'dialekt', 'twardy', 'sprzedawać', 'płyta',
        'przyszłość', 'wiersz', 'biedny', 'mapa', 'zamieszkiwać', 'piątek', 'lipiec', 'ciągle', 'lew', 'marzec',
        'jesień', 'obchodzić', 'proszę', 'planeta', 'dzięki', '50', 'wilk', 'łatwy', 'milion', 'gwiazdozbiór', '40',
        'termin', 'pusty', 'wtedy', 'wydać', 'struktura', 'sobota', 'popularny', 'ssak', 'gałąź', 'pieniądze',
        'przeciw', 'technika', 'pół', 'zdrowy', 'więcej', 'świeży', 'szyja', 'zamknąć', 'sala', 'akt', 'wiara',
        'pływać', 'pszczoła', 'projekt', 'jedyny', 'bać się', 'zewnętrzny', 'płaski', 'spokojny', 'zwyczaj', 'organ',
        'sztuczny', 'delikatny', 'typowy', 'literatura', 'budować', 'strój', 'literacki', 'krzew', 'zawód', 'łagodny',
        'następny', 'chiński', 'Słońce', 'telewizja', 'zwykły', 'widoczny', 'piosenka', 'silnik', 'waga', 'płeć',
        'Stany Zjednoczone', 'komputerowy', 'dlatego', 'służba', 'suchy', 'modlitwa', 'sierpień', 'dość', 'kino',
        'siedziba', 'miód', 'lotniczy', 'Chiny', 'specjalny', 'dym', 'zysk', 'podatek', 'wejście', 'pomagać', 'zakres',
        'zwrot', 'fakt', 'otwór', 'pokryć', 'most', 'sprawiać', 'wybór', 'osiągnąć', 'siódmy', 'społeczeństwo',
        'fabryka', 'słyszeć', 'internetowy', 'mysz', 'przyjemność', 'bądź', 'przechodzić', 'próba', 'panować',
        'straszny', 'wrogość', 'zabić', 'przedsiębiorstwo', 'jajo', 'rzeczywistość', 'ziarno', 'restauracja',
        'współczesny', 'krok', 'daleko', 'składnik', 'kanał', 'kalendarz', 'odległość', 'przeciwnik', 'złapać', 'czyn',
        'mur', 'zmienić', 'kurs', 'niebezpieczny', 'Czechy', 'wtorek', 'ocena', 'postawić', 'okolica', 'usterka',
        'zjeść', 'umiejętność', 'zapomnieć', 'Anglia', 'dzielić', 'pamiętać', 'szef', 'majątek', 'kosztować', 'port',
        'spotkać', 'autor', 'los', 'dwudziesty', 'zdarzenie', 'ósmy', 'ślub', 'dopiero', 'prywatny', 'pojechać',
        'policjant', 'sędzia', 'średni', 'rzeczownik', 'ciepło', 'badać', 'rasa', 'Dania', 'koszula', 'okazja',
        'przeciwko', 'usługa', 'stawiać', 'otwierać', 'efekt', 'kapelusz', 'kaczka', 'własność', 'model', 'mięsień',
        'zgodnie', 'podać', 'piłka nożna', 'reakcja', 'znów', 'przejaw', 'doświadczenie', 'dziura', 'bitwa', 'korzyść',
        'bank', 'Indie', 'gniew', 'przedstawienie', 'naj-', 'czasownik', 'jakość', 'dłoń', 'osioł', 'hotel', 'sprzedaż',
        'kierowca', 'różnica', 'bohater', 'masło', 'wrażenie', 'brzydki', 'rozmiar', 'rzadko', 'królowa', 'przejść',
        'olej', 'śniadanie', 'artysta', 'pisarz', 'zamykać', 'opowiadać', 'plaża', 'słoneczny', 'prędkość', 'mąka',
        'Polak', 'ciąża', 'gęsty', 'zero', 'dawno', 'przyjemny', 'spowodować', 'brudny', 'wytwarzać', 'opisać',
        'okrągły', 'ciecz', 'ludowy', 'wrócić', 'dokonywać', 'kiedyś', 'wola', 'waluta', 'całkowity', 'wykonanie',
        'dziwny', 'tracić', 'wczesny', 'jazda', 'uderzać', 'radio', 'wyrażenie', 'wizyta', 'rana', 'daleki', 'czasem',
        'wybrać', 'fałszywy', 'pozwalać', 'złożony', 'klasztor', 'zawodnik', 'minerał', 'znajdować', 'przyszły',
        'koszt', 'spodnie', 'przepis', 'stacja', 'rzadki', 'grób', 'mecz', 'dyskusja', 'sport', 'nieszczęście', 'pieśń',
        'wolno', 'handel', 'korzeń', 'łaciński', 'penis', 'październik', 'głód', 'srebro', 'kontakt', 'budzić',
        'czwartek', 'otaczać', 'prostytutka', 'tradycja', 'znosić', 'gniazdo', 'złodziej', 'godny', 'powoli', 'zegar',
        'urzędnik', 'Rumunia', 'Egipt', 'metr', 'kolano', 'przestać', 'uderzyć', 'Turcja', 'przerwa', 'skończyć',
        'jeżeli', 'sądzić', 'transport', 'dobro', 'przygotować', 'szkolny', 'mi', 'małpa', 'udać się', 'krzyż',
        'atmosfera', 'klient', 'brązowy', 'tłuszcz', 'ślad', 'mebel', 'zakończenie', 'USA', 'coraz', 'wódka', 'danie',
        'sos', 'liczny', 'oddawać', 'zachowywać się', 'kontrola', 'mózg', 'bezpieczeństwo', 'duński', 'oglądać',
        'dodawać', 'urodziny', 'figura', 'powiat', 'dzisiejszy', 'otworzyć', 'armia', 'zboże', 'czerwiec', 'opłata',
        'skutek', 'suma', 'wyjście', 'operacja', 'niedźwiedź', 'matematyka', 'zniszczyć', 'pokazywać', 'zbudować',
        'kontynent', 'dwanaście', 'dodatkowy', 'fragment', 'łódź', 'szary', '80', 'ojczyzna', 'tańczyć',
        'Boże Narodzenie', 'umysł', 'Ameryka', 'ogólny', 'azjatycki', 'bydło', 'biblioteka', 'żart', 'rozwiązanie',
        'lecieć', 'pojęcie', 'konstrukcja', 'Austria', 'niech', 'niebezpieczeństwo', 'tyle', 'podłoga', 'wysoko',
        'odczuwać', 'obrona', 'żelazo', 'studiować', 'środa', 'park', 'powstawać', 'łuk', 'dolina', 'przygotowywać',
        'obywatelka', 'gotowy', 'miecz', 'uchodzić', 'szkoda', 'zgodny', 'dzielnica', 'prezent', 'sukces', '90',
        'lista', 'towarzystwo', 'podział', 'wysiłek', 'stado', 'tajemnica', 'kłopot', 'łyżka', 'lęk', 'cebula',
        'płacić', 'no', 'profesor', 'w czasie', 'niszczyć', 'm.in.', 'Afganistan', 'usuwać', 'pomysł', 'mrówka',
        'Kraków', 'gotować', 'norma', 'całkiem', 'finansowy', 'tor', 'temu', 'jądro', 'wracać', 'Białoruś', 'koza',
        'Jezus', 'płaszcz', 'wierny', 'różowy', 'widok', 'sygnał', 'cesarz', 'potrzebny', 'nagły', 'wypowiedź', 'kosz',
        'królestwo', 'samochodowy', 'artystyczny', '60', 'Chrystus', 'anioł', 'przejście', 'krzesło', 'sprzęt',
        'wskazywać', 'ksiądz', 'strumień', 'metalowy', 'wykonywanie', 'zmarły', 'chrześcijański', 'cierpienie', 'scena',
        'przeszkoda', 'zimno', 'mieć na imię', 'przychodzić', 'słoń', 'odwaga', 'przedstawiciel', 'aktor', 'ciekawy',
        'dziewiąty', 'Australia', 'smutny', 'biec', 'przyprawa', 'prawny', 'tłum', 'interes', 'studia', 'świątynia',
        'pijany', 'użytkownik', 'kostka', 'wywołać', 'wujek', 'dodać', 'robotnik', 'powszechny', 'dyrektor',
        'umieszczać', 'robota', 'narząd', 'szwedzki', 'turecki', 'otrzymywać', 'produkować', 'zabawka', 'kolejowy',
        'nastrój', 'szkło', 'ziemski', 'farba', 'bycie', 'zainteresowanie', 'relacja', 'ciężar', 'pasmo', 'wynosić',
        'obóz', 'marka', 'szczególny', 'lis', 'wada', 'Holandia', 'bogini', 'uciekać', 'dziewczynka', 'przestępstwo',
        'wycieczka', 'tablica', 'kolej', 'natychmiast', 'zdolny', 'wysyłać', 'błoto', 'Szwajcaria', 'orzeł', 'oddech',
        'motyl', 'kilometr', 'umożliwiać', 'żydowski', 'gospodarka', 'pomóc', 'wciąż', 'intensywny', 'wakacje', 'pytać',
        'utrzymywać', 'gdyby', 'malować', 'samica', 'istotny', 'idea', 'posiłek', 'wszelki', 'seks', 'pomarańczowy',
        'handlowy', 'czoło', 'przynieść', 'teoria', 'staw', 'obserwować', 'po prostu', 'Izrael', 'opieka', 'mgła',
        'osobisty', 'znaczyć', 'impreza', 'powieść', 'archipelag', 'nadmierny', 'reguła', 'pojedynczy', 'szklanka',
        'wóz', 'odcinek', 'telewizyjny', 'róża', 'zawartość', 'ryż', 'poznać', 'jedynie', 'polityk', 'zwycięstwo',
        'władca', 'żaba', 'zbiornik', 'mistrz', 'procent', 'zawodowy', 'obowiązywać', 'choć', 'kura', 'ćwiczenie',
        'chłop', 'świeca', 'promień', 'spadek', 'trudność', 'szereg', 'cień', 'epoka', 'umieścić', 'doskonały',
        'ozdobny', 'chociaż', 'kościelny', 'wyścig', 'zamiast', 'ocean', 'koncert', 'wybierać', 'znaczny',
        'chrześcijaństwo', 'bar', 'gołąb', 'postawa', 'kolacja', 'wina', 'pora', 'pragnąć', 'zakończyć', 'bieda',
        'Węgry', 'smutek', 'biuro', 'wieczorem', 'dolny', 'byk', 'burza', 'katolicki', 'książę', 'samiec', 'grzech',
        'naukowiec', 'kończyć', 'dorosły', 'zapalenie', 'przyjaźń', 'godność', 'fotografia', 'nieprzyjemny', 'mądry',
        'klimat', 'muzeum', 'treść', 'rezultat', 'dane', 'cisza', 'zaś', 'psychiczny', 'starać się', 'lampa', 'wesoły',
        'Unia Europejska', 'dziób', 'traktować', 'przeprowadzać', 'piętro', 'niezwykły', 'wieża', 'pokarm', 'igła',
        'strefa', 'spór', 'dać się', 'Estonia', 'poprzedni', 'dowód', 'pasek', 'dno', 'klub', 'wysłać', 'rachunek',
        'odkryć', 'gardło', 'piętnaście', 'nauczycielka', 'bawić się', 'królewski', 'lotnisko', 'wzrok', 'moralny',
        'odzież', 'śmiać się', 'mnóstwo', 'czapka', 'wywodzić się', 'sądowy', 'papież', 'plemię', 'kartka', '70',
        'tani', 'pożar', 'półwysep', 'kult', 'łąka', 'lot', 'broda', 'wspólnota', 'wreszcie', 'lata', 'powolny',
        'przybyć', 'mocz', 'Słowacja', 'grunt', 'pomidor', 'dokładny', 'stowarzyszenie', 'r.', 'wojenny', 'odważny',
        'podnosić', 'zeszły', 'ośrodek', 'ozdoba', 'wraz', 'tytoń', 'obrót', 'zmęczony', 'głośny', 'parlament',
        'uzyskać', 'wydawać się', 'budowla', 'jakby', 'wniosek', 'zajęcie', 'rysunek', 'wzgląd', 'pająk',
        'Morze Śródziemne', 'Litwa', 'jednocześnie', 'diabeł', 'pozostać', 'kłaść', 'skłonność', 'dziecięcy',
        'korzystać', 'Belgia', 'lina', 'wystawa', 'ciągnąć', 'pacjent', 'świadczyć', 'narkotyk', 'sukienka',
        'techniczny', 'zaraz', 'Wielka Brytania', 'medycyna', 'przyjechać', 'powstanie', 'trwały', 'wzbudzać',
        'czynnik', 'strata', 'podróżować', 'hałas', 'rak', 'talerz', 'plecy', 'późny', 'deska', 'boleć', 'spaść',
        'martwy', 'łańcuch', 'czeski', 'filmowy', 'wygrać', 'zaufanie', 'alkoholowy', 'płakać', 'głupiec', 'poczta',
        'dar', 'w formie', 'narodowość', 'podnieść', 'okręt', 'gęś', 'oś', 'nasiono', 'śmiech', 'tył', 'woleć', 'islam',
        'sowa', 'wpaść', 'panna', 'chyba', 'osiągnięcie', 'trudno', 'robak', 'otoczenie', 'konflikt', 'centralny',
        'pustynia', 'gabinet', 'poruszać', 'hasło', 'świecić', 'kij', 'przód', 'etap', 'większy', 'filozofia',
        'jedenaście', 'wstyd', 'kobiecy', 'urzędowy', 'czekolada', 'ciemność', 'zapis', 'ubogi', 'wioska', 'biskup',
        'doktor', 'oczywiście', 'wisieć', 'tłumaczenie', 'kwestia', 'kogut', 'oddać', 'ślepy', 'latać', 'babka',
        'dokonać', 'bogactwo', 'śmieć', 'analiza', 'strzelać', 'mierzyć', 'ciotka', 'blady', 'pozostawać', 'tłumaczyć',
        'muzyk', 'zgadzać się', 'paliwo', 'Żyd', 'postępować', 'bronić', 'szkodliwy', 'zanim', 'włosy', 'zatrzymać',
        'aktywny', 'skala', 'cmentarz', 'spadać', 'głupota', 'kieszeń', 'lustro', 'zając', 'szlachetny', 'wątpliwość',
        'letni', 'cyfra', 'lokalny', 'pomarańcza', 'skierować', 'poeta', 'okropny', 'istnienie', 'minister', 'umierać',
        'faza', 'dalej', 'następować', 'zrozumieć', 'dostęp', 'opuścić', 'katastrofa', 'pojemnik', 'pojawiać się',
        'ulegać', 'lekarstwo', 'przymiotnik', 'nieść', 'Chorwacja', 'inaczej', 'plama', 'policzek', 'chęć', 'królik',
        'bóstwo', 'ryzyko', 'zamiar', 'przebywać', 'radiowy', 'pałac', 'zarówno', 'nazywać się', 'paczka',
        'gospodarstwo', 'kolumna', 'graniczyć', 'biologia', 'upadek', 'wprowadzać', 'Kościół', 'rzucić', 'plus',
        'wkrótce', 'ładunek', 'sprawiedliwość', 'kolorowy', 'kapusta', 'wybory', 'uśmiech', 'zakon', 'nocny', 'kurwa',
        'Adam', 'na pewno', 'przemysłowy', 'oba', 'wyjątkowy', 'najpierw', 'futro', 'pisanie', 'planować', 'jadalny',
        'adres', 'przenosić', 'dojść', 'częściowo', 'bezpośrednio', 'wybuch', 'głodny', 'oprzeć', 'tata', 'wzgórze',
        'fizyka', 'planetoida', 'zgromadzenie', 'codzienny', 'tarcza', 'św.', 'dziennik', 'krzyczeć', 'Norwegia', '0',
        'organizować', 'urodzić się', 'wynikać', 'krawędź', 'pełnić', 'Albania', 'uciec', 'czasami', 'przekazywać',
        'praktyka', 'pokrywać', 'płot', 'oczekiwać', 'użyć', 'rządzić', 'ustawa', 'rolnik',
    )
