from .. import Provider as BaseProvider

# source: https://bit.ly/32nqRv7


class Provider(BaseProvider):
    jobs = [
        "Diretor geral e gestor executivo, de empresas",
        "Diretor de vendas",
        "Diretores de investigação e desenvolvimento",
        "Diretor de produção na agricultura",
        "Diretor de produção animal",
        "Diretor de produção florestal",
        "Diretor de produção na pesca",
        "Diretor de produção na aquicultura",
        "Diretor das indústrias transformadoras",
        "Diretor das indústrias extrativas",
        "Diretor das indústrias de construção e de engenharia civil",
        "Diretor de compras",
        "Diretor de transportes",
        "Diretores de armazenagem, distribuição e relacionados",
        "Diretores dos serviços das tecnologias da informação e comunicação",
        "Diretor dos serviços de cuidados de crianças",
        "Diretor dos serviços de cuidados a pessoas idosas",
        "Diretor dos serviços de apoio social",
        "Diretor dos serviços de educação",
        "Diretor de sucursais de bancos, serviços financeiros e de seguros",
        "Oficiais e outros profissionais das forças e serviços de segurança, com funções de comando,",
        "Diretor e gerente do comércio por grosso",
        "Diretor e gerente de outros serviços, n.e.",
        "Astrónomo",
        "Oceanógrafo",
        "Botânico",
        "Farmacologista e outros especialistas relacionados",
        "Consultor de atividades das pescas",
        "Diretor geral e gestor executivo, de empresas",
        "Diretores de investigação e desenvolvimento",
        "Diretor de produção na agricultura",
        "Diretor de produção na aquicultura",
        "Diretores de armazenagem, distribuição e relacionados",
        "Diretores dos serviços das tecnologias da informação e comunicação",
        "Diretor dos serviços de cuidados de crianças",
        "Diretor dos serviços de cuidados a pessoas idosas",
        "Diretor dos serviços de apoio social",
        "Diretor dos serviços de educação",
        "Diretor de sucursais de bancos, serviços financeiros e de seguros",
        "Oficiais e outros profissionais das forças e serviços de segurança, com funções de comando,",
        "Diretor e gerente do comércio por grosso",
        "Diretor e gerente de outros serviços, n.e.",
        "Farmacologista e outros especialistas relacionados",
        "Consultor de atividades das pescas",
        "Engenheiro de construção de edifícios",
        "Engenheiro de obras de engenharia civil",
        "Engenheiro mecânico",
        "Engenheiro de minas",
        "Engenheiro metalúrgico",
        "Engenheiro eletrotécnico",
        "Engenheiro eletrónico",
        "Engenheiro de telecomunicações",
        "Designer de têxteis e moda",
        "Topógrafo",
        "Enfermeiro de cuidados gerais",
        "Enfermeiro especialista em reabilitação",
        "Enfermeiro especialista em saúde infantil e pediátrica",
        "Enfermeiro especialista em saúde mental e psiquiátrica",
        "Enfermeiro especialista em enfermagem comunitária",
        "Enfermeiro especialista em enfermagem médico cirúrgica",
        "Enfermeiro especialista em saúde materna e obstétrica",
        "Profissional paramédico",
        "Farmacêutico",
        "Fisioterapeuta",
        "Dietista e nutricionista",
        "Audiologista",
        "Terapeuta da fala",
        "Terapeuta ocupacional",
        "Professor dos ensinos básico (2.º e 3.º ciclos) e secundário",
        "Professor do ensino básico (1.º ciclo)",
        "Educador de infância",
        "Especialista em métodos de ensino",
        "Professor do ensino especial",
        "Especialista em recursos humanos",
        "Especialista em formação e desenvolvimento de recursos humanos",
        "Especialista em relações públicas",
        "Analista de sistemas",
        "Programador de software",
        "Programador Web e de multimédia",
        "Programador de aplicações",
        "Engenheiro de construção de edifícios",
        "Engenheiro de obras de engenharia civil",
        "Engenheiro de telecomunicações",
        "Enfermeiro especialista em reabilitação",
        "Enfermeiro especialista em saúde infantil e pediátrica",
        "Enfermeiro especialista em saúde mental e psiquiátrica",
        "Enfermeiro especialista em enfermagem comunitária",
        "Enfermeiro especialista em enfermagem médico cirúrgica",
        "Enfermeiro especialista em saúde materna e obstétrica",
        "Professor dos ensinos básico (2.º e 3.º ciclos) e secundário",
        "Professor do ensino básico (1.º ciclo)",
        "Especialista em métodos de ensino",
        "Especialista em recursos humanos",
        "Especialista em formação e desenvolvimento de recursos humanos",
        "Especialista em relações públicas",
        "Programador Web e de multimédia",
        "Administrador e especialista de conceção de base de dados",
        "Administrador de sistemas",
        "Especialista de redes informáticas",
        "Notário",
        "Curador de museus",
        "Bibliotecários e outros especialistas de informação relacionados",
        "Sociólogo",
        "Antropólogo",
        "Filósofo",
        "Psicólogo",
        "Especialista do trabalho social",
        "Ministro de culto",
        "Filólogo",
        "Tradutor",
        "Intérprete e outros linguistas",
        "Escultor",
        "Caricaturista",
        "Compositor",
        "Músico",
        "Coreógrafo",
        "Diretor de fotografia e de som, montador e relacionados",
        "Ator",
        "Disc Jockey",
        "Técnico de engenharia civil",
        "Técnico de eletricidade",
        "Técnico de eletrónica",
        "Técnico de inspeção de veículos",
        "Técnico da metalurgia de base e da indústria extrativa",
        "Desenhadores e técnicos afins",
        "Técnico de gás",
        "Encarregado da indústria extrativa",
        "Encarregados das indústrias da madeira e cortiça",
        "Encarregados das indústrias da pasta, papel, impressão",
        "Encarregados das indústrias refinarias de petróleo",
        "Encarregados das indústrias da transformação de minerais não metálicos",
        "Administrador e especialista de conceção de base de dados",
        "Especialista de redes informáticas",
        "Bibliotecários e outros especialistas de informação relacionados",
        "Diretor de fotografia e de som, montador e relacionados",
        "Técnico da metalurgia de base e da indústria extrativa",
        "Encarregado da indústria extrativa",
        "Encarregados das indústrias da madeira e cortiça",
        "Encarregados das indústrias da pasta, papel, impressão",
        "Encarregados das indústrias da transformação de minerais não metálicos",
        "Encarregado da construção",
        "Técnico de operação de instalações de produção de energia",
        "Técnico de operação de incineradores",
        "Técnico de operação de instalações de tratamento de água",
        "Técnico de controlo de instalações da indústria química",
        "Técnico de operação de instalações de refinação de petróleo e gás natural",
        "Técnico de controlo de instalações de produção de metais",
        "Técnico das ciências da vida (excetos ciências médicas)",
        "Técnico florestal (inclui cinegético)",
        "Oficial maquinista de navios",
        "Oficial de convés e piloto de navios",
        "Piloto de aeronaves",
        "Controlador de tráfego aéreo",
        "Técnico de cardiopneumografia",
        "Técnico de medicina nuclear",
        "Técnico de radioterapia",
        "Técnico de análises clínicas",
        "Técnico de anatomia patológica, citológica e tanatológica",
        "Auxiliar de enfermagem",
        "Parteira",
        "Profissionais de nível intermédio da medicina tradicional e complementar",
        "Terapeuta e assistente dentário",
        "Técnico de registos médicos e de informação sobre saúde",
        "Técnico dos serviços de saúde comun",
        "Técnico e assistente, de fisioterapia",
        "Assistente de médicos",
        "Pessoal de ambulâncias",
        "Corretor de bolsa, cambista",
        "Representante comercial",
        "Corretor comercial",
        "Despachante, transitário",
        "Organizador de conferências e eventos",
        "Encarregado de armazém",
        "Fiscal e encarregado de portagem",
        "Supervisor de cargas e descargas",
        "Secretário da área jurídica",
        "Secretário administrativo e executivo",
        "Encarregados das indústrias metalúrgicas de base e fabrico de produtos metálicos",
        "Técnico de operação de instalações de produção de energia",
        "Técnico de operação de incineradores",
        "Técnico de operação de instalações de tratamento de água",
        "Técnico de controlo de instalações da indústria química",
        "Técnico de operação de instalações de refinação de petróleo e gás natural",
        "Técnico de controlo de instalações de produção de metais",
        "Técnico das ciências da vida (excetos ciências médicas)",
        "Técnico florestal (inclui cinegético)",
        "Técnico de anatomia patológica, citológica e tanatológica",
        "Profissionais de nível intermédio da medicina tradicional e complementar",
        "Técnico de registos médicos e de informação sobre saúde",
        "Técnico dos serviços de saúde comunitária",
        "Técnico e assistente, de fisioterapia",
        "Corretor de bolsa, cambista",
        "Despachante, transitário",
        "Organizador de conferências e eventos",
        "Fiscal e encarregado de portagem",
        "Supervisor de cargas e descargas",
        "Secretário administrativo e executivo",
        "Secretário da área da medicina",
        "Técnico de nível intermédio dos serviços jurídicos e relacionados",
        "Técnico de nível intermédio de apoio social",
        "Jogador profissional de futebol",
        "Ciclista profissional",
        "Treinador de desportos",
        "Árbitro (juiz) de desportos",
        "Fotógrafo",
        "Técnicos de galerias, bibliotecas, arquivos e museus",
        "Toureiro, cavaleiro tauromáquico e outros profissionais similares",
        "Técnico operador das tecnologias de informação e comunicação (TIC)",
        "Técnico de apoio aos utilizadores das TIC",
        "Técnico em redes e sistemas de computadores",
        "Técnico da Web",
        "Técnico de emissões de rádio",
        "Técnico de emissões de televisão",
        "Técnico de gravação audiovisual",
        "Técnico de sistemas de comunicações via rádio",
        "Técnico de telecomunicações",
        "Empregado de escritório em geral",
        "Técnico de secretariado",
        "Empregado de banca nos casinos e outros empregados de apostas",
        "Penhorista e prestamista",
        "Empregado das agências de viagem",
        "Pessoal de informação administrativa",
        "Rececionista, exceto de hotel",
        "Outro pessoal de receção e de informação a clientes",
        "Operador de contabilidade e escrituração comercial",
        "Operador de dados de processamento de pagamentos",
        "Empregado de aprovisionamento",
        "Empregado de armazém",
        "Controlador de transportes terrestres de passageiros",
        "Controlador de transportes terrestres de mercadorias",
        "Empregado de biblioteca",
        "Carteiro",
        "Codificador, revisor de provas",
        "Escrivão",
        "Empregado de serviço de pessoal",
        "Outro pessoal de apoio de tipo administrativo, n.e.",
        "Técnico de nível intermédio dos serviços jurídicos e relacionados",
        "Técnico de nível intermédio de apoio social",
        "Técnicos de galerias, bibliotecas, arquivos e museus",
        "Toureiro, cavaleiro tauromáquico e outros profissionais similares",
        "Técnico operador das tecnologias de informação e comunicação (TIC)",
        "Técnico de apoio aos utilizadores das TIC",
        "Técnico de emissões de televisão",
        "Técnico de sistemas de comunicações via rádio",
        "Empregado de escritório em geral",
        "Empregado de banca nos casinos e outros empregados de apostas",
        "Empregado das agências de viagem",
        "Pessoal de informação administrativa",
        "Outro pessoal de receção e de informação a clientes",
        "Operador de contabilidade e escrituração comercial",
        "Operador de dados de processamento de pagamentos",
        "Empregado de aprovisionamento",
        "Controlador de transportes terrestres de passageiros",
        "Controlador de transportes terrestres de mercadorias",
        "Codificador, revisor de provas",
        "Empregado de serviço de pessoal",
        "Outro pessoal de apoio de tipo administrativo, n.e.",
        "Fiscal e cobrador de transportes públicos",
        "Cozinheiro",
        "Cabeleireiro e barbeiro",
        "Esteticista",
        "Massagista de estética",
        "Manicura, pedicura e calista",
        "Governante doméstico",
        "Pessoal de companhia e ajudantes de quarto",
        "Agente funerário",
        "Embalsamador",
        "Instrutor de condução",
        "Vendedor ambulante de produtos alimentares",
        "Vendedor em loja (estabelecimento)",
        "Operador de caixa",
        "Vendedor ao domicílio",
        "Assistente de venda de alimentos ao balcão",
        "Auxiliar de cuidados de crianças",
        "Auxiliar de professor",
        "Auxiliar de saúde",
        "Ajudante familiar",
        "Bombeiro",
        "Porteiro de hotelaria",
        "Segurança (vigilante privado), outros porteiros",
        "Outro pessoal dos serviços de proteção e segurança",
        "Agricultor e trabalhador qualificado de cereais e outras culturas extensivas",
        "Trabalhador qualificado da jardinagem",
        "Produtor e trabalhador qualificado na produção de bovinos",
        "Produtor e trabalhador qualificado na produção de ovinos e caprinos",
        "Produtor e trabalhador qualificado na produção de suínos",
        "Produtor e trabalhador qualificado na produção de outros animais de carne",
        "Avicultor e trabalhador qualificado da avicultura",
        "Sericicultor e trabalhador qualificado da sericicultura",
        "Motosserrista",
        "Sapador florestal",
        "Fiscal e cobrador de transportes públicos",
        "Encarregado de limpeza e de trabalhos domésticos em escritórios, hotéis e outros",
        "Pessoal de companhia e ajudantes de quarto",
        "Vendedor ambulante de produtos alimentares",
        "Vendedor em loja (estabelecimento)",
        "Assistente de venda de alimentos ao balcão",
        "Segurança (vigilante privado), outros porteiros",
        "Outro pessoal dos serviços de proteção e segurança",
        "Agricultor e trabalhador qualificado de cereais e outras culturas extensivas",
        "Trabalhador qualificado da jardinagem",
        "Produtor e trabalhador qualificado na produção de bovinos",
        "Produtor e trabalhador qualificado na produção de ovinos e caprinos",
        "Produtor e trabalhador qualificado na produção de suínos",
        "Produtor e trabalhador qualificado na produção de outros animais de carne",
        "Sericicultor e trabalhador qualificado da sericicultura",
        "Aquicultor (aquacultor)",
        "Pescador de águas interiores ",
        "Construtor de casas rudimentares",
        "Pedreiro",
        "Calceteiro",
        "Assentador de refratários",
        "Polidor da pedra",
        "Canteiro",
        "Cimenteiro",
        "Armador de ferro",
        "Montador de alvenarias e de pré",
        "Carpinteiro de limpos e de tosco",
        "Carpinteiro naval",
        "Montador de andaimes",
        "Espalhador de betuminosos",
        "Colocador de telhados e de coberturas",
        "Assentador de tacos e afagador de madeira",
        "Ladrilhador",
        "Estucador",
        "Trabalhador qualificado em isolamentos acústicos e térmicos",
        "Vidraceiro",
        "Canalizador",
        "Montador de tubagens",
        "Instalador de ar condicionado e de sistemas de refrigeração",
        "Pintor de construções",
        "Colocador de papel de parede, pintor decorador",
        "Pintor à pistola de superfícies",
        "Construtor de casas rudimentares",
        "Colocador de telhados e de coberturas",
        "Assentador de tacos e afagador de madeira",
        "Trabalhador qualificado em isolamentos acústicos e térmicos",
        "Instalador de ar condicionado e de sistemas de refrigeração",
        "Colocador de papel de parede, pintor decorador",
        "Envernizador",
        "Limpador de chaminés e de outras estruturas de edifícios",
        "Operador de fundição",
        "Trabalhador de corte a oxigas",
        "Bate chapa de veículos automóveis",
        "Funileiro e caldeireiro",
        "Serralheiro civil",
        "Outro preparador e montador de estruturas metálicas",
        "Forjador e ferreiro",
        "Operador de prensa de forjar, estampador",
        "Serralheiro de moldes, cunhos, cortantes",
        "Regulador e operador de máquinas ferramentas convencionais para trabalhar metais",
        "Regulador e operador de máquinas ferramentas de comando numérico computorizado",
        "Retificador de rodas, polidor e afiador de metais",
        "Mecânico e reparador de veículos automóveis",
        "Técnico de manutenção e reparação de motores de avião",
        "Mecânico e reparador, de máquinas agrícolas e industriais",
        "Reparador de bicicletas",
        "Trabalhador qualificado do fabrico e reparação de instrumentos de precisão",
        "Trabalhador qualificado do fabrico e afinação de instrumentos musicais",
        "Joalheiro",
        "Filigranista",
        "Soprador de artigos de vidro",
        "Cortador de vidro",
        "Polidor e acabador de artigos de vidro",
        "Lapidador e gravador, de vidro, cerâmica e outros materiais",
        "Pintor decorador de vidro, cerâmica e outros materiais",
        "Artesão de artigos em madeira",
        "Artesão de rendas, bordados e tapeçarias, manuais",
        "Artesão de artigos de couro",
        "Operador de pré-impressão",
        "Eletricista de construções",
        "Instalador de sistemas solares térmicos",
        "Instalador de sistemas solares fotovoltaicos",
        "Instalador de sistemas de bioenergia",
        "Limpador de chaminés e de outras estruturas de edifícios",
        "Bate chapa de veículos automóveis",
        "Outro preparador e montador de estruturas metálicas",
        "Operador de prensa de forjar, estampador",
        "Serralheiro de moldes, cunhos, cortantes",
        "Regulador e operador de máquinas ferramentas convencionais para trabalhar metais",
        "Retificador de rodas, polidor e afiador de metais",
        "Mecânico e reparador de veículos automóveis",
        "Técnico de manutenção e reparação de motores de avião",
        "Mecânico e reparador, de máquinas agrícolas e industriais",
        "Reparador de bicicletas",
        "Trabalhador qualificado do fabrico e reparação de instrumentos de precisão",
        "Polidor e acabador de artigos de vidro",
        "Lapidador e gravador, de vidro, cerâmica e outros materiais",
        "Pintor decorador de vidro, cerâmica e outros materiais",
        "Artesão de rendas, bordados e tapeçarias, manuais",
        "Eletricista de construções",
        "Instalador de sistemas solares térmicos",
        "Instalador de sistemas solares fotovoltaicos",
        "Eletromecânico, eletricista e outros instaladores de máquinas e equipamentos elétricos",
        "Instalador e reparador de linhas elétricas",
        "Mecânico e reparador de equipamentos eletrónicos",
        "Instalador e reparador, de tecnologias de informação e comunicação",
        "Cortador de carne",
        "Salsicheiro",
        "Preparador e conservador de peixe",
        "Padeiro",
        "Confeiteiro",
        "Trabalhador do fabrico de produtos lácteos",
        "Conserveiro de frutas, legumes",
        "Trabalhador do tratamento da madeira",
        "Marceneiro",
        "Tanoeiro, embutidor e outros similares a marceneiro",
        "Operador de máquinas e de equipamentos para trabalhar madeira",
        "Alfaiate e costureiro",
        "Peleiro",
        "Chapeleiro",
        "Riscador de moldes e cortador de tecidos",
        "Bordador",
        "Trabalhador de costura",
        "Estofador",
        "Curtidor de peles",
        "Maleiro",
        "Correeiro",
        "Mergulhador",
        "Carregador de fogo e dinamitador",
        "Fumigador e outros controladores, de pragas e ervas daninhas",
        "Salineiro",
        "Trabalhador de fabrico de foguetes (fogueteiro)",
        "Mineiro",
        "Trabalhador das pedreiras",
        "Operador de instalações de processamento de minérios",
        "Operador de instalações de processamento de rochas",
        "Perfurador de poços, sondador",
        "Operador de máquinas para trabalhar o cimento",
        "Operador de máquinas para trabalhar a pedra",
        "Operador de máquinas para trabalhar outros minerais",
        "Operador de instalações de fornos e de primeira transformação de metais",
        "Operador de instalações de fornos de segunda fusão, vazadores e laminadores de metais.",
        "Operador de instalações de tratamento térmico de metais",
        "Eletromecânico, eletricista e outros instaladores de máquinas e equipamentos elétricos",
        "Instalador e reparador de linhas elétricas",
        "Mecânico e reparador de equipamentos eletrónicos",
        "Instalador e reparador, de tecnologias de informação e comunicação",
        "Preparador e conservador de peixe",
        "Trabalhador do fabrico de produtos lácteos",
        "Conserveiro de frutas, legumes",
        "Trabalhador do tratamento da madeira",
        "Tanoeiro, embutidor e outros similares a marceneiro",
        "Operador de máquinas e de equipamentos para trabalhar madeira",
        "Riscador de moldes e cortador de tecidos",
        "Trabalhador de costura",
        "Carregador de fogo e dinamitador",
        "Fumigador e outros controladores, de pragas e ervas daninhas",
        "Trabalhador de fabrico de foguetes (fogueteiro)",
        "Operador de instalações de processamento de minérios",
        "Operador de instalações de processamento de rochas",
        "Perfurador de poços, sondador",
        "Operador de máquinas para trabalhar o cimento",
        "Operador de máquinas para trabalhar a pedra",
        "Operador de máquinas para trabalhar outros minerais",
        "Operador de instalações de fornos e de primeira transformação de metais",
        "Operador de instalações de fornos de segunda fusão, vazadores e laminadores de metais.",
        "Operador de instalações de tratamento térmico de metais",
        "Operador de instalações de trefilagem e estiragem",
        "Operador de máquinas de revestimento, metalização e acabamento de metais",
        "Operador de instalações e máquinas para moagem de substâncias químicas",
        "Operador de instalações e máquinas para tratamento térmico de produtos químicos",
        "Operador de instalações e máquinas,",
        "Operador de instalações e máquinas, para reação e verificação de produtos químicos",
        "Operador de instalações e máquinas, para petróleo e gás",
        "Operador de instalações e máquinas para outros tratamentos químicos",
        "Operador de máquinas para o fabrico de produtos de borracha",
        "Operador de máquinas para o fabrico de produtos de matérias plásticas",
        "Operador de máquinas para o fabrico de produtos de papel",
        "Operador de máquinas de tecer e tricotar",
        "Operador de máquinas de costura",
        "Operador de máquinas de branquear, tingir e limpar, tecidos e outros têxteis",
        "Operador de máquinas de fabrico de calçado",
        "Operador de máquinas de lavandaria",
        "Operador de máquinas de preparação de carne e peixe",
        "Operador de máquinas de moagem de cereais, de transformação de arroz e de fabricação de",
        "Operador de máquinas de produção e refinação de açúcar",
        "Operador de máquinas para preparação de chá, café e cacau",
        "Operador de máquinas para preparação de vinhos e outras bebidas",
        "Operador de máquinas para o fabrico do tabaco",
        "Operador de instalações para o fabrico de pasta de papel e de papel",
        "Operador de instalações para o trabalho da madeira e cortiça",
        "Operador de instalações para o fabrico de vidro",
        "Operador de máquinas a vapor e caldeiras",
        "Operador de máquinas para fabrico de produtos de arame",
        "Montador de maquinaria mecânica",
        "Maquinista de locomotivas",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Condutor de motociclos",
        "Motorista de táxis",
        "Motorista de automóveis ligeiros e carrinhas",
        "Motorista de autocarros",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Motorista de veículos pesados de mercadorias",
        "Operador de máquinas agrícolas e florestais, móveis",
        "Operador de máquinas de escavação, terraplenagem",
        "Operador de gruas, guindastes",
        "Operador de instalações de trefilagem e estiragem",
        "Operador de máquinas de revestimento, metalização e acabamento de metais",
        "Operador de instalações e máquinas para moagem de substâncias químicas",
        "Operador de instalações e máquinas para tratamento térmico de produtos químicos",
        "Operador de instalações e máquinas, para filtragem e separação química",
        "Operador de instalações e máquinas, para reação e verificação de produtos químicos",
        "Operador de instalações e máquinas, para petróleo e gás",
        "Operador de instalações e máquinas para outros tratamentos químicos",
        "Operador de máquinas para o fabrico de produtos de borracha",
        "Operador de máquinas para o fabrico de produtos de matérias plásticas",
        "Operador de máquinas de tecer e tricotar",
        "Operador de máquinas de costura",
        "Operador de máquinas de branquear, tingir e limpar, tecidos e outros têxteis",
        "Operador de máquinas de fabrico de calçado",
        "Operador de máquinas de lavandaria",
        "Operador de máquinas de preparação de carne e peixe",
        "Operador de máquinas de moagem de cereais, de transformação de arroz e de fabricação de",
        "Operador de máquinas de produção e refinação de açúcar",
        "Operador de máquinas para preparação de chá, café e cacau",
        "Operador de máquinas para preparação de vinhos e outras bebidas",
        "Operador de máquinas para o fabrico do tabaco",
        "Operador de instalações para o fabrico de pasta de papel e de papel",
        "Operador de instalações para o trabalho da madeira e cortiça",
        "Operador de instalações para o fabrico de vidro",
        "Operador de máquinas a vapor e caldeiras",
        "Operador de máquinas para fabrico de produtos de arame",
        "Montador de maquinaria mecânica",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Motorista de automóveis ligeiros e carrinhas",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Motorista de veículos pesados de mercadorias",
        "Operador de máquinas de escavação, terraplenagem",
        "Operador de gruas, guindastes",
        "Tripulação de convés de navios",
        "Trabalhador de limpeza em escritórios, hotéis",
        "Lavadeiro e engomador de roupa",
        "Lavador de veículos",
        "Lavador de janelas",
        "Trabalhador não qualificado da floresta",
        "Trabalhador não qualificado das minas",
        "Trabalhador não qualificado das pedreiras",
        "Trabalhador não qualificado de engenharia civil",
        "Trabalhador não qualificado da construção de edifícios",
        "Embalador manual da indústria transformadora",
        "Condutor de veículos acionados à mão ou ao pé",
        "Condutor de veículos de tração animal",
        "Carregadores e descarregadores não qualificados de mercadorias",
        "Preparador de refeições rápidas",
        "Ajudante de cozinha",
        "Prestador de serviços na rua",
        "Vendedor ambulante",
        "Trabalhador da recolha de resíduos",
        "Trabalhador da triagem de resíduos",
        "Cantoneiro de limpeza",
        "Empregado de lavabos",
        "Estafeta",
        "Bagageiro",
        "Distribuidor de mercadorias",
        "Colocador de anúncios",
        "Leitor de contadores",
        "Coletor de dinheiro em máquinas de venda automática",
        "Coveiro",
    ]
